// Persistence of Vision Ray Tracer Scene Description File
// File: TwistedWeed.inc
// Vers: 3.1
// Desc: Macro for creating a twisted bush-like plant
// Date: 
// Auth: Micha Riser (mriser@usa.net)  
//       visit my homepage:             http://www.geocities.com/SiliconValley/Pines/7992/
//       the POVRay Objects Collection: http://povobjects.fsn.net/
//       modified by TdeG / 07-2002 
//			 transformation to macro by TdeG, November 2008

#macro TwistedWeed()
#ifndef (Randomer) #local Randomer=848; #end
#ifndef (Tex) 		 #local Tex=texture {pigment {rgb<0.572,0.418,0.165>}} #end
#ifndef (Thresh) 	 #local Thresh=0.2;   #end
#ifndef (Twigs)    #local Twigs=25;     #end
#ifndef (Segments) #local Segments=20;  #end

//----- WEED source code BEGIN

#local r1 = seed(Randomer);   //by changing this you can create various similar objects
 
#declare Weed =
union { 
  #local z2=0; 
  #while (z2<Twigs) // number of twigs
    #local z2=z2+1; 
 
    #local xkor=0; 
    #local ykor=0; 
    #local zkor=0; 
    #local zahler=-1; 
    #local winkel1=0; 
    #local winkel2=0; 
 
    blob {threshold Thresh 
      #while (zahler<Segments) // number of segments per twig
        #local zahler=zahler+1; 
        #local dwinkel1=(rand(r1)-0.5)*55; 
        #local dwinkel2=(rand(r1)-0.5)*55; 
        #local winkel1=winkel1+dwinkel1; 
        #local winkel2=winkel2+dwinkel2; 
 
        cylinder{<0,0,0>,<0,0,0.40+zahler*0.005>,0.2-(zahler*0.0099),1 
          rotate x*winkel2 
          rotate y*winkel1 
          translate <xkor,ykor,zkor>
        } 
 
        #local zkor=zkor+cos(radians(winkel1))*cos(radians(winkel2))*0.5; 
        #local xkor=xkor+cos(radians(winkel2))*sin(radians(winkel1))*0.5; 
        #local ykor=ykor+sin(radians(-winkel2))*0.5; 
      #end 
 
      scale 0.35 
 
      #local rotatex=-90; 
      rotate x*rotatex 
      rotate y*z2*14.4 
      translate <0,0,0> 
    } // end blob
  #end 
 
  //pigment{ rgb<0.572,0.418,0.165>  }  //modify this to change the objects' color
  texture {Tex}
} // end of union

#end	//of macro

//--- Weed source code end

//test:
/*
TwistedWeed()
object {Weed}
plane{y,-0.1 pigment{rgb<0.67,0.67,0.67>}} 
cylinder { <-1, 0, 0>, <1, 0, 0>, 0.01 pigment {rgb <1,0,0>}}
cylinder { <0, -1, 0>, <0, 1, 0>, 0.01 pigment {rgb <0,1,0>}}
cylinder { <0, 0, -1>, <0, 0, 1>, 0.01 pigment {rgb <0,0,1>}}

//perspective (default) camera
camera {
  location  <-2.0, 2.0, -5.0>
  look_at   <0.0, 0.0,  0.0>
  right     x*image_width/image_height
}

// create a regular point light source
light_source {
  0*x                  // light's position (translated below)
  color rgb <1,1,1>    // light's color
  translate <-20, 40, -20>
}

light_source {
  0*x                  // light's position (translated below)
  color rgb <1,1,1>    // light's color
  translate <20, 40, -20>
  shadowless
}
*/